@@ -17,11 +17,24 @@
 from enum import Enum
 from pm4py.util import constants
 from pm4py.algo.discovery.dfg import algorithm as dfg_discovery
-from pm4py.algo.discovery.footprints.outputs import Outputs
 from pm4py.objects.conversion.log import converter
-from pm4py.objects.log.log import EventLog
+from pm4py.objects.log.obj import EventLog
 from pm4py.util import xes_constants
 from pm4py.util import exec_utils
+from enum import Enum
+
+
+class Outputs(Enum):
+    DFG = "dfg"
+    SEQUENCE = "sequence"
+    PARALLEL = "parallel"
+    START_ACTIVITIES = "start_activities"
+    END_ACTIVITIES = "end_activities"
+    ACTIVITIES = "activities"
+    SKIPPABLE = "skippable"
+    ACTIVITIES_ALWAYS_HAPPENING = "activities_always_happening"
+    MIN_TRACE_LENGTH = "min_trace_length"
+    TRACE = "trace"
 
 
 class Parameters(Enum):
