@@ -14,8 +14,8 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.conformance.alignments import algorithm as ali
-from pm4py.algo.conformance.alignments.variants import state_equation_a_star as star
+from pm4py.algo.conformance.alignments.petri_net import algorithm as ali
+from pm4py.algo.conformance.alignments.petri_net.variants import state_equation_a_star as star
 import sys
 from pm4py.statistics.variants.log import get as variants_module
 from pm4py.algo.conformance.tokenreplay import algorithm as token_replay
@@ -25,6 +25,7 @@ from pm4py.statistics.attributes.log.select import select_attributes_from_log_fo
 from pm4py.objects.conversion.log import converter as log_converter
 from enum import Enum
 from pm4py.util import exec_utils
+import deprecation
 
 
 class Parameters(Enum):
@@ -76,6 +77,7 @@ def get_decision_tree(log, net, initial_marking, final_marking, decision_point=N
     return dt, list(X.columns.values.tolist()), targets
 
 
+@deprecation.deprecated('2.2.5', '3.0.0', details='use pm4py.algo.decision_mining.algorithm instead')
 def apply(log, net, initial_marking, final_marking, decision_point=None, attributes=None, parameters=None):
     """
     Gets the essential information (features, target class and names of the target class)
