@@ -15,7 +15,7 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.objects.log.util import insert_classifier, log, sampling, \
-    sorting, index_attribute, get_class_representation, get_log_representation, get_prefixes, \
+    sorting, index_attribute, get_class_representation, get_prefixes, \
     get_log_encoded, interval_lifecycle, log_regex, basic_filter
 import pkgutil
 
