@@ -154,22 +154,16 @@ def convert_timestamp_columns_in_df(df, timest_format=None, timest_columns=None)
         Dataframe with timestamp columns converted
 
     """
-    needs_conversion = check_pandas_ge_024()
     for col in df.columns:
         if timest_columns is None or col in timest_columns:
             if df[col].dtype == 'object':
                 try:
                     if timest_format is None:
-                        if needs_conversion:
-                            df[col] = pd.to_datetime(df[col], utc=True)
-                        else:
-                            df[col] = pd.to_datetime(df[col])
+                        # makes operations faster if non-ISO8601 but anyhow regular dates are provided
+                        df[col] = pd.to_datetime(df[col], utc=True, infer_datetime_format=True)
                     else:
-                        if needs_conversion:
-                            df[col] = pd.to_datetime(df[col], utc=True, format=timest_format)
-                        else:
-                            df[col] = pd.to_datetime(df[col])
-                except ValueError:
+                        df[col] = pd.to_datetime(df[col], utc=True, format=timest_format)
+                except:
                     # print("exception converting column: "+str(col))
                     pass
     return df
