@@ -22,6 +22,8 @@ from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
 from pm4py.util import exec_utils
 from pm4py.util import constants
 from enum import Enum
+from collections import Counter
+from typing import Optional, Dict, Any, List, Tuple
 
 
 class Parameters(Enum):
@@ -34,6 +36,96 @@ class Parameters(Enum):
     KEEP_ONCE_PER_CASE = "keep_once_per_case"
 
 
+def __add_left_0(stri: str, target_length: int) -> str:
+    """
+    Adds left 0s to the current string until the target length is reached
+
+    Parameters
+    ----------------
+    stri
+        String
+    target_length
+        Target length
+
+    Returns
+    ----------------
+    stri
+        Revised string
+    """
+    while len(stri) < target_length:
+        stri = "0" + stri
+    return stri
+
+
+def get_events_distribution(log: EventLog, distr_type: str = "days_month", parameters: Optional[Dict[str, Any]] = None) -> Tuple[List[str], List[int]]:
+    """
+    Gets the distribution of the events in the specified dimension
+
+    Parameters
+    ----------------
+    log
+        Event log
+    distr_type
+        Type of distribution:
+        - days_month => Gets the distribution of the events among the days of a month (from 1 to 31)
+        - months => Gets the distribution of the events among the months (from 1 to 12)
+        - years => Gets the distribution of the events among the years of the event log
+        - hours => Gets the distribution of the events among the hours of a day (from 0 to 23)
+        - days_week => Gets the distribution of the events among the days of a week (from Monday to Sunday)
+    parameters
+        Parameters of the algorithm, including:
+        - Parameters.TIMESTAMP_KEY
+
+    Returns
+    ----------------
+    x
+        Points (of the X-axis)
+    y
+        Points (of the Y-axis)
+    """
+    if parameters is None:
+        parameters = {}
+
+    timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, DEFAULT_TIMESTAMP_KEY)
+
+    timestamp_values = []
+    for trace in log:
+        for event in trace:
+            timestamp_values.append(event[timestamp_key])
+
+    values = None
+    all_values = None
+    if distr_type == "days_month":
+        values = Counter(x.day for x in timestamp_values)
+        all_values = Counter({i: 0 for i in range(1, 32)})
+    elif distr_type == "months":
+        values = Counter(x.month for x in timestamp_values)
+        all_values = Counter({i: 0 for i in range(1, 13)})
+    elif distr_type == "years":
+        values = Counter(x.year for x in timestamp_values)
+        all_values = Counter({i: 0 for i in range(min(values), max(values)+1)})
+    elif distr_type == "hours":
+        values = Counter(x.hour for x in timestamp_values)
+        all_values = Counter({i: 0 for i in range(0, 24)})
+    elif distr_type == "days_week":
+        values = Counter(x.weekday() for x in timestamp_values)
+        all_values = Counter({i: 0 for i in range(0, 7)})
+
+    # make sure that all the possible values appear
+    for v in all_values:
+        if v not in values:
+            values[v] = all_values[v]
+
+    values = sorted([(__add_left_0(str(x), 2), y) for x, y in values.items()])
+
+    if distr_type == "days_week":
+        mapping = {"00": "Monday", "01": "Tuesday", "02": "Wednesday", "03": "Thursday", "04": "Friday",
+                   "05": "Saturday", "06": "Sunday"}
+        values = [(mapping[x[0]], x[1]) for x in values]
+
+    return [x[0] for x in values], [x[1] for x in values]
+
+
 def get_all_trace_attributes_from_log(log):
     """
     Get all trace attributes from the log
@@ -175,7 +267,7 @@ def get_kde_numeric_attribute(log, attribute, parameters=None):
     """
 
     if type(log) is EventLog:
-        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM)
+        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters={"deepcopy": False, "include_case_attributes": False})
     else:
         event_log = log
 
@@ -209,7 +301,7 @@ def get_kde_numeric_attribute_json(log, attribute, parameters=None):
     """
 
     if type(log) is EventLog:
-        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM)
+        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters={"deepcopy": False, "include_case_attributes": False})
     else:
         event_log = log
 
@@ -242,7 +334,7 @@ def get_kde_date_attribute(log, attribute=DEFAULT_TIMESTAMP_KEY, parameters=None
     """
 
     if type(log) is EventLog:
-        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM)
+        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters={"deepcopy": False, "include_case_attributes": False})
     else:
         event_log = log
 
@@ -276,7 +368,7 @@ def get_kde_date_attribute_json(log, attribute=DEFAULT_TIMESTAMP_KEY, parameters
     """
 
     if type(log) is EventLog:
-        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM)
+        event_log = log_conversion.apply(log, variant=log_conversion.TO_EVENT_STREAM, parameters={"deepcopy": False, "include_case_attributes": False})
     else:
         event_log = log
 
