@@ -15,11 +15,23 @@
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
 from pm4py.util.xes_constants import DEFAULT_NAME_KEY, DEFAULT_TIMESTAMP_KEY
-from pm4py.statistics.parameters import Parameters
 from pm4py.util import exec_utils, variants_util, constants
 
 import numpy as np
 
+from pm4py.util import constants
+from enum import Enum
+
+
+class Parameters(Enum):
+    ATTRIBUTE_KEY = constants.PARAMETER_CONSTANT_ATTRIBUTE_KEY
+    ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
+    START_TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_START_TIMESTAMP_KEY
+    TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_TIMESTAMP_KEY
+    CASE_ID_KEY = constants.PARAMETER_CONSTANT_CASEID_KEY
+    MAX_NO_POINTS_SAMPLE = "max_no_of_points_to_sample"
+    KEEP_ONCE_PER_CASE = "keep_once_per_case"
+
 
 def get_language(log, parameters=None):
     """
