@@ -18,7 +18,7 @@ import tempfile
 
 from graphviz import Digraph
 
-from pm4py.objects.petri.petrinet import Marking
+from pm4py.objects.petri_net.obj import Marking
 from pm4py.util import exec_utils
 from pm4py.visualization.petrinet.parameters import Parameters
 
@@ -56,13 +56,15 @@ def apply(net, initial_marking, final_marking, decorations=None, parameters=None
     image_format = exec_utils.get_param_value(Parameters.FORMAT, parameters, "png")
     debug = exec_utils.get_param_value(Parameters.DEBUG, parameters, False)
     set_rankdir = exec_utils.get_param_value(Parameters.RANKDIR, parameters, None)
+    font_size = exec_utils.get_param_value(Parameters.FONT_SIZE, parameters, "12")
+
     return graphviz_visualization(net, image_format=image_format, initial_marking=initial_marking,
                                   final_marking=final_marking, decorations=decorations, debug=debug,
-                                  set_rankdir=set_rankdir)
+                                  set_rankdir=set_rankdir, font_size=font_size)
 
 
 def graphviz_visualization(net, image_format="png", initial_marking=None, final_marking=None, decorations=None,
-                           debug=False, set_rankdir=None):
+                           debug=False, set_rankdir=None, font_size="12"):
     """
     Provides visualization for the petrinet
 
@@ -95,6 +97,8 @@ def graphviz_visualization(net, image_format="png", initial_marking=None, final_
     if decorations is None:
         decorations = {}
 
+    font_size = str(font_size)
+
     filename = tempfile.NamedTemporaryFile(suffix='.gv')
     viz = Digraph(net.name, filename=filename.name, engine='dot', graph_attr={'bgcolor': 'transparent'})
     if set_rankdir:
@@ -108,17 +112,17 @@ def graphviz_visualization(net, image_format="png", initial_marking=None, final_
         if t.label is not None:
             if t in decorations and "label" in decorations[t] and "color" in decorations[t]:
                 viz.node(str(id(t)), decorations[t]["label"], style='filled', fillcolor=decorations[t]["color"],
-                         border='1')
+                         border='1', fontsize=font_size)
             else:
-                viz.node(str(id(t)), str(t.label))
+                viz.node(str(id(t)), str(t.label), fontsize=font_size)
         else:
             if debug:
-                viz.node(str(id(t)), str(t.name))
+                viz.node(str(id(t)), str(t.name), fontsize=font_size)
             elif t in decorations and "color" in decorations[t] and "label" in decorations[t]:
                 viz.node(str(id(t)), decorations[t]["label"], style='filled', fillcolor=decorations[t]["color"],
-                         fontsize='8')
+                         fontsize=font_size)
             else:
-                viz.node(str(id(t)), "", style='filled', fillcolor="black")
+                viz.node(str(id(t)), "", style='filled', fillcolor="black", fontsize=font_size)
 
     # places
     viz.attr('node', shape='circle', fixedsize='true', width='0.75')
@@ -137,16 +141,16 @@ def graphviz_visualization(net, image_format="png", initial_marking=None, final_
 
     for p in places_sort_list:
         if p in initial_marking:
-            viz.node(str(id(p)), str(initial_marking[p]), style='filled', fillcolor="green")
+            viz.node(str(id(p)), str(initial_marking[p]), style='filled', fillcolor="green", fontsize=font_size)
         elif p in final_marking:
-            viz.node(str(id(p)), "", style='filled', fillcolor="orange")
+            viz.node(str(id(p)), "", style='filled', fillcolor="orange", fontsize=font_size)
         else:
             if debug:
-                viz.node(str(id(p)), str(p.name))
+                viz.node(str(id(p)), str(p.name), fontsize=font_size)
             else:
                 if p in decorations and "color" in decorations[p] and "label" in decorations[p]:
                     viz.node(str(id(p)), decorations[p]["label"], style='filled', fillcolor=decorations[p]["color"],
-                             fontsize='6')
+                             fontsize=font_size)
                 else:
                     viz.node(str(id(p)), "")
 
@@ -155,13 +159,12 @@ def graphviz_visualization(net, image_format="png", initial_marking=None, final_
     for a in arcs_sort_list:
         if a in decorations and "label" in decorations[a] and "penwidth" in decorations[a]:
             viz.edge(str(id(a.source)), str(id(a.target)), label=decorations[a]["label"],
-                     penwidth=decorations[a]["penwidth"])
+                     penwidth=decorations[a]["penwidth"], fontsize=font_size)
         elif a in decorations and "color" in decorations[a]:
-            viz.edge(str(id(a.source)), str(id(a.target)), color=decorations[a]["color"])
+            viz.edge(str(id(a.source)), str(id(a.target)), color=decorations[a]["color"], fontsize=font_size)
         else:
-            viz.edge(str(id(a.source)), str(id(a.target)))
+            viz.edge(str(id(a.source)), str(id(a.target)), fontsize=font_size)
     viz.attr(overlap='false')
-    viz.attr(fontsize='11')
 
     viz.format = image_format
 
